@@ -10,7 +10,7 @@ import (
 
 func main() {
 	checks := scanner.GetRegisteredRules()
-	fmt.Printf("%d checks require linting\n", len(checks))
+	fmt.Printf("Checks requiring linting: %d\n", len(checks))
 
 	linter := &linter{}
 
@@ -18,6 +18,6 @@ func main() {
 		linter.lint(check)
 	}
 
-	fmt.Printf("%d checks require attention\n", linter.count)
-	os.Exit(linter.exitCode)
+	fmt.Printf("Checks requiring action:  %d\n", linter.count)
+	os.Exit(linter.exitCode())
 }
