@@ -36,6 +36,18 @@ func (attr *HCLAttribute) Type() cty.Type {
 	return attr.Value().Type()
 }
 
+func (attr *HCLAttribute) IsString() bool {
+	return attr.Value().Type() == cty.String
+}
+
+func (attr *HCLAttribute) IsNumber() bool {
+	return attr.Value().Type() == cty.Number
+}
+
+func (attr *HCLAttribute) IsBool() bool {
+	return attr.Value().Type() == cty.Bool
+}
+
 func (attr *HCLAttribute) Value() (ctyVal cty.Value) {
 	if attr == nil {
 		return cty.NilVal
@@ -293,11 +305,17 @@ func (attr *HCLAttribute) IsEmpty() bool {
 			return false
 		case *hclsyntax.ConditionalExpr:
 			return false
+		case *hclsyntax.LiteralValueExpr:
+			return false
 		case *hclsyntax.TemplateExpr:
 			// walk the parts of the expression to ensure that it has a literal value
 			for _, p := range t.Parts {
-				part := p.(*hclsyntax.LiteralValueExpr)
-				if part != nil && !part.Val.IsNull() {
+				switch pt := p.(type) {
+				case *hclsyntax.LiteralValueExpr:
+					if pt != nil && !pt.Val.IsNull() {
+						return false
+					}
+				case *hclsyntax.ScopeTraversalExpr:
 					return false
 				}
 			}
