@@ -3,6 +3,8 @@ package rules
 import (
 	"fmt"
 
+	"github.com/zclconf/go-cty/cty"
+		
 	"github.com/tfsec/tfsec/pkg/result"
 	"github.com/tfsec/tfsec/pkg/severity"
 
@@ -76,7 +78,7 @@ func init() {
 
 			for _, attribute := range resourceBlock.GetAttributes() {
 				if attribute.Name() == "default" {
-					if !attribute.IsEmpty() {
+					if attribute.Type() == cty.String && attribute.IsResolvable() {
 						set.Add(result.New(resourceBlock).
 							WithDescription(fmt.Sprintf("Variable '%s' includes a potentially sensitive default value.", resourceBlock.FullName())).
 							WithRange(attribute.Range()).
