@@ -3,19 +3,15 @@ package rules
 import (
 	"fmt"
 
+	"github.com/zclconf/go-cty/cty"
+	
 	"github.com/tfsec/tfsec/pkg/result"
 	"github.com/tfsec/tfsec/pkg/severity"
-
 	"github.com/tfsec/tfsec/pkg/provider"
-
 	"github.com/tfsec/tfsec/internal/app/tfsec/hclcontext"
-
 	"github.com/tfsec/tfsec/internal/app/tfsec/block"
-
 	"github.com/tfsec/tfsec/pkg/rule"
-
 	"github.com/tfsec/tfsec/internal/app/tfsec/security"
-
 	"github.com/tfsec/tfsec/internal/app/tfsec/scanner"
 )
 
@@ -70,7 +66,7 @@ func init() {
 
 			for _, attribute := range resourceBlock.GetAttributes() {
 				if security.IsSensitiveAttribute(attribute.Name()) {
-					if !attribute.IsEmpty() {
+					if attribute.Type() == cty.String && attribute.IsResolvable() {
 						set.Add(result.New(resourceBlock).
 							WithDescription(fmt.Sprintf("Local '%s' includes a potentially sensitive value which is defined within the project.", resourceBlock.FullName())).
 							WithRange(attribute.Range()).
