@@ -21,29 +21,30 @@ import (
 
 func Test_IgnoreAll(t *testing.T) {
 
-	results := scanSource(`
+	results := scanHCL(`
 resource "aws_security_group_rule" "my-rule" {
     type        = "ingress"
     cidr_blocks = ["0.0.0.0/0"] // tfsec:ignore:*
+	description = "testing"
 }
-`)
+`, t)
 	assert.Len(t, results, 0)
 
 }
 
 func Test_IgnoreLineAboveTheBlock(t *testing.T) {
-	results := scanSource(`
+	results := scanHCL(`
 // tfsec:ignore:*
 resource "aws_security_group_rule" "my-rule" {
     type        = "ingress"
     cidr_blocks = ["0.0.0.0/0"] 
 }
-`)
+`, t)
 	assert.Len(t, results, 0)
 }
 
 func Test_IgnoreLineAboveTheLine(t *testing.T) {
-	results := scanSource(`
+	results := scanHCL(`
 
 resource "aws_security_group_rule" "my-rule" {
     type        = "ingress"
@@ -51,18 +52,18 @@ resource "aws_security_group_rule" "my-rule" {
     cidr_blocks = ["0.0.0.0/0"] 
 	description = "test security group rule"
 }
-`)
+`, t)
 	assert.Len(t, results, 0)
 }
 func Test_IgnoreLineOnTheLine(t *testing.T) {
-	results := scanSource(`
+	results := scanHCL(`
 resource "aws_security_group_rule" "my-rule" {
     type        = "ingress"
 	
     cidr_blocks = ["0.0.0.0/0"] # tfsec:ignore:AWS006
 	description = "test security group rule"
 }
-`)
+`, t)
 	assert.Len(t, results, 0)
 }
 func Test_IgnoreSpecific(t *testing.T) {
@@ -71,7 +72,7 @@ func Test_IgnoreSpecific(t *testing.T) {
 		ID:              "ABC123",
 		RequiredLabels:  []string{"bad"},
 		DefaultSeverity: severity.Error,
-		CheckFunc: func(set result.Set, resourceBlock *block.Block, _ *hclcontext.Context) {
+		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 			set.Add(
 				result.New(resourceBlock).WithDescription("example problem").WithRange(resourceBlock.Range()).WithSeverity(severity.Error),
 			)
@@ -82,59 +83,59 @@ func Test_IgnoreSpecific(t *testing.T) {
 		ID:              "DEF456",
 		RequiredLabels:  []string{"bad"},
 		DefaultSeverity: severity.Error,
-		CheckFunc: func(set result.Set, resourceBlock *block.Block, _ *hclcontext.Context) {
+		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 			set.Add(
 				result.New(resourceBlock).WithDescription("example problem").WithRange(resourceBlock.Range()).WithSeverity(severity.Error),
 			)
 		},
 	})
 
-	results := scanSource(`
+	results := scanHCL(`
 resource "bad" "my-bad" {} //tfsec:ignore:ABC123
-`)
+`, t)
 	require.Len(t, results, 1)
 	assert.Equal(t, results[0].RuleID, "DEF456")
 
 }
 
 func Test_IgnoreWithExpDateIfDateBreachedThenDontIgnore(t *testing.T) {
-	results := scanSource(`
+	results := scanHCL(`
 resource "aws_security_group_rule" "my-rule" {
     type        = "ingress"
 	
     cidr_blocks = ["0.0.0.0/0"] # tfsec:ignore:AWS006:exp:2000-01-02
 	description = "test security group rule"
 }
-`)
+`, t)
 	assert.Len(t, results, 1)
 }
 
 func Test_IgnoreWithExpDateIfDateNotBreachedThenIgnoreIgnore(t *testing.T) {
-	results := scanSource(`
+	results := scanHCL(`
 resource "aws_security_group_rule" "my-rule" {
     type        = "ingress"
 	
     cidr_blocks = ["0.0.0.0/0"] # tfsec:ignore:AWS006:exp:2221-01-02
 	description = "test security group rule"
 }
-`)
+`, t)
 	assert.Len(t, results, 0)
 }
 
 func Test_IgnoreWithExpDateIfDateInvalidThenDontIgnoreTheIgnore(t *testing.T) {
-	results := scanSource(`
+	results := scanHCL(`
 resource "aws_security_group_rule" "my-rule" {
    type        = "ingress"
 
    cidr_blocks = ["0.0.0.0/0"] # tfsec:ignore:AWS006:exp:2221-13-02
 	description = "test security group rule"
 }
-`)
+`, t)
 	assert.Len(t, results, 1)
 }
 
 func Test_IgnoreAboveResourceBlockWithExpDateIfDateNotBreachedThenIgnoreIgnore(t *testing.T) {
-	results := scanSource(`
+	results := scanHCL(`
 # tfsec:ignore:AWS006:exp:2221-01-02
 resource "aws_security_group_rule" "my-rule" {
     type        = "ingress"
@@ -142,18 +143,18 @@ resource "aws_security_group_rule" "my-rule" {
     cidr_blocks = ["0.0.0.0/0"]
 	description = "test security group rule"
 }
-`)
+`, t)
 	assert.Len(t, results, 0)
 }
 
 func Test_IgnoreAboveResourceBlockWithExpDateAndMultipleIgnoresIfDateNotBreachedThenIgnoreIgnore(t *testing.T) {
-	results := scanSource(`
+	results := scanHCL(`
 # tfsec:ignore:AWS006:exp:2221-01-02 #tfsec:ignore:AWS018
 resource "aws_security_group_rule" "my-rule" {
     type        = "ingress"
 	
     cidr_blocks = ["0.0.0.0/0"]
 }
-`)
+`, t)
 	assert.Len(t, results, 0)
 }
